@@ -3,7 +3,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Run::Role::Runner;
 
-our $VERSION = '0.040';
+our $VERSION = '0.041';
 
 use Moose::Role;
 use namespace::autoclean;
@@ -171,8 +171,8 @@ sub _run_cmd {
     waitpid($pid, 0);
 
     if (my $status = ($? >> 8)) {
-        if ($self->fatal_errors and $self->quiet and  $self->zilla->logger->get_debug) {
-            $self->log([ 'executed: %s', $command ]) ;
+        if ($self->fatal_errors and $self->quiet and not $self->zilla->logger->get_debug) {
+            $self->log([ 'executed: %s', $command ]);
             $self->log($_) for @lines;
         }
 
@@ -200,6 +200,10 @@ sub _eval_cmd {
     my $error = $@;
 
     if (defined $error and $error ne '') {
+        if ($self->fatal_errors and $self->quiet and not $self->zilla->logger->get_debug) {
+            $self->log([ 'evaluated: %s', $code]);
+        }
+
         $self->${ $self->fatal_errors ? \'log_fatal' : $self->quiet ? \'log_debug' : \'log'}
             ([ 'evaluation died: %s', $error ]);
     }
